@@ -88,7 +88,7 @@ def try_upsert(collection: StandardCollection, record_batch: RecordBatch, force=
             else:
                 # Update ingested_documents and ingested_bytes metrics
                 ingested_documents.labels(region_label, tenant_label, fabric_label, workflow_label).inc()
-                ingested_bytes.labels(region_label, tenant_label, fabric_label, workflow_label).inc_by(len(json.dumps(r)))
+                ingested_bytes.labels(region_label, tenant_label, fabric_label, workflow_label).inc(len(json.dumps(r)))
 
         if len(to_update) > 0:
             for i, r in enumerate(collection.update_many(to_update)):
